# klue-microservice

Easily create and deploy a Flask-based REST api running as a Docker container on amazon AWS

## Example

See
[klue-microservice-helloworld](https://github.com/erwan-lemonnier/klue-microservice-helloworld)
for an example of a minimal REST api implemented with klue-microservice, and
ready to deploy on docker containers in Amazon EC2.


